==> flink-table-api-java-1.9.0-sources.jar: org/apache/flink/table/operations/CatalogQueryOperation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.operations;

import org.apache.flink.annotation.Internal;
import org.apache.flink.table.api.TableSchema;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * Describes a relational operation that was created from a lookup to a catalog.
 */
@Internal
public class CatalogQueryOperation implements QueryOperation {

	private final List<String> tablePath;
	private final TableSchema tableSchema;

	public CatalogQueryOperation(List<String> tablePath, TableSchema tableSchema) {
		this.tablePath = tablePath;
		this.tableSchema = tableSchema;
	}

	public List<String> getTablePath() {
		return tablePath;
	}

	@Override
	public TableSchema getTableSchema() {
		return tableSchema;
	}

	@Override
	public String asSummaryString() {
		Map<String, Object> args = new LinkedHashMap<>();
		args.put("path", tablePath);
		args.put("fields", tableSchema.getFieldNames());

		return OperationUtils.formatWithChildren("CatalogTable", args, getChildren(), Operation::asSummaryString);
	}

	@Override
	public List<QueryOperation> getChildren() {
		return Collections.emptyList();
	}

	@Override
	public <T> T accept(QueryOperationVisitor<T> visitor) {
		return visitor.visit(this);
	}
}

==> flink-table-api-java-1.10.0-sources.jar: org/apache/flink/table/operations/CatalogQueryOperation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.operations;

import org.apache.flink.annotation.Internal;
import org.apache.flink.table.api.TableSchema;
import org.apache.flink.table.catalog.ObjectIdentifier;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * Describes a relational operation that was created from a lookup to a catalog.
 */
@Internal
public class CatalogQueryOperation implements QueryOperation {

	private final ObjectIdentifier tableIdentifier;
	private final TableSchema tableSchema;

	public CatalogQueryOperation(ObjectIdentifier tableIdentifier, TableSchema tableSchema) {
		this.tableIdentifier = tableIdentifier;
		this.tableSchema = tableSchema;
	}

	public ObjectIdentifier getTableIdentifier() {
		return tableIdentifier;
	}

	@Override
	public TableSchema getTableSchema() {
		return tableSchema;
	}

	@Override
	public String asSummaryString() {
		Map<String, Object> args = new LinkedHashMap<>();
		args.put("identifier", tableIdentifier);
		args.put("fields", tableSchema.getFieldNames());

		return OperationUtils.formatWithChildren("CatalogTable", args, getChildren(), Operation::asSummaryString);
	}

	@Override
	public List<QueryOperation> getChildren() {
		return Collections.emptyList();
	}

	@Override
	public <T> T accept(QueryOperationVisitor<T> visitor) {
		return visitor.visit(this);
	}
}
